@@ -2,6 +2,7 @@ package steampipeconfig
 
 import (
 	"fmt"
+	"golang.org/x/exp/maps"
 	"log"
 	"sort"
 	"strings"
@@ -164,12 +165,12 @@ func (u *ConnectionUpdates) getConnectionsToCreate(alreadyCreatedConnectionPlugi
 	// put connections into a map to avoid dupes
 	var connectionMap = make(map[string]*modconfig.Connection, len(updateConnections))
 	for _, connection := range updateConnections {
-		// if this connection is an aggregator, instantiate its first child connection instead
-		if connection.Type == modconfig.ConnectionTypeAggregator {
-			connection = connection.FirstChild()
-		}
 
 		connectionMap[connection.Name] = connection
+		// if this connection is an aggregator, add all its children
+		for _, child := range connection.Connections {
+			connectionMap[child.Name] = child
+		}
 	}
 	// NOTE - we may have already created some connection plugins (if they have dynamic schema)
 	// - remove these from list of plugins to create
@@ -211,6 +212,12 @@ func (u *ConnectionUpdates) String() string {
 	return op.String()
 }
 
+func (u *ConnectionUpdates) AsNotification() *SchemaUpdateNotification {
+	return NewSchemaUpdateNotification(
+		maps.Keys(u.Update),
+		maps.Keys(u.Delete))
+}
+
 func getSchemaHashesForDynamicSchemas(requiredConnectionData ConnectionDataMap, connectionState ConnectionDataMap) (map[string]string, map[string]*ConnectionPlugin, error) {
 	log.Printf("[TRACE] getSchemaHashesForDynamicSchemas")
 	// for every required connection, check the connection state to determine whether the schema mode is 'dynamic'
