@@ -6,7 +6,7 @@ import (
 
 type DashboardCategoryFold struct {
 	Title     *string `cty:"title" hcl:"title" json:"title,omitempty"`
-	Threshold int     `cty:"threshold" hcl:"threshold" json:"threshold,omitempty"`
+	Threshold *int    `cty:"threshold" hcl:"threshold" json:"threshold,omitempty"`
 	Icon      *string `cty:"icon" hcl:"icon" json:"icon,omitempty"`
 }
 
